#[non_exhaustive]pub struct CreateVectorBucketInput {
pub vector_bucket_name: Option<String>,
pub encryption_configuration: Option<EncryptionConfiguration>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vector_bucket_name: Option<String>The name of the vector bucket to create.
encryption_configuration: Option<EncryptionConfiguration>The encryption configuration for the vector bucket. By default, if you don't specify, all new vectors in Amazon S3 vector buckets use server-side encryption with Amazon S3 managed keys (SSE-S3), specifically AES256.
An array of user-defined tags that you would like to apply to the vector bucket that you are creating. A tag is a key-value pair that you apply to your resources. Tags can help you organize and control access to resources. For more information, see Tagging for cost allocation or attribute-based access control (ABAC).
You must have the s3vectors:TagResource permission in addition to s3vectors:CreateVectorBucket permission to create a vector bucket with tags.
Implementations
Sourceimpl CreateVectorBucketInput
impl CreateVectorBucketInput
Sourcepub fn vector_bucket_name(&self) -> Option<&str>
pub fn vector_bucket_name(&self) -> Option<&str>
The name of the vector bucket to create.
Sourcepub fn encryption_configuration(&self) -> Option<&EncryptionConfiguration>
pub fn encryption_configuration(&self) -> Option<&EncryptionConfiguration>
The encryption configuration for the vector bucket. By default, if you don't specify, all new vectors in Amazon S3 vector buckets use server-side encryption with Amazon S3 managed keys (SSE-S3), specifically AES256.
An array of user-defined tags that you would like to apply to the vector bucket that you are creating. A tag is a key-value pair that you apply to your resources. Tags can help you organize and control access to resources. For more information, see Tagging for cost allocation or attribute-based access control (ABAC).
You must have the s3vectors:TagResource permission in addition to s3vectors:CreateVectorBucket permission to create a vector bucket with tags.
Sourceimpl CreateVectorBucketInput
impl CreateVectorBucketInput
Sourcepub fn builder() -> CreateVectorBucketInputBuilder
pub fn builder() -> CreateVectorBucketInputBuilder
Creates a new builder-style object to manufacture CreateVectorBucketInput.